<?php
namespace FM\Factory;

use Doctrine\ORM\EntityManager;

class MinhasTarefasFactory
{

    protected $connection;

    public function __construct(EntityManager $entityManager) {

        $this->connection = $entityManager->getConnection();
    }

    // Funções da Tela de Lista de Tarefas
    public function getPlace () {
        $sql = "SELECT NRLOCALCLIENTE, NMLOCALCLIENTE
                FROM FCM_LOCALCLI
                JOIN FCM_TIPOLOCALCLI
                  ON FCM_TIPOLOCALCLI.NRTIPOLOCALCLI = FCM_LOCALCLI.NRTIPOLOCALCLI
                 AND FCM_TIPOLOCALCLI.NRORG = FCM_LOCALCLI.NRORG
                WHERE FCM_TIPOLOCALCLI.IDTIPOLOCALCLI IN ('2', '3')";

        $std = $this->connection->prepare($sql);

        $std->execute();
        return $std->fetchAll();
    }

    public function getSituation () {
      $sql = "SELECT DISTINCT FCM_CHECKLISTAGEND.IDSITUACAOAGEND AS NRIDSITUACAOAGEND,
                CASE FCM_CHECKLISTAGEND.IDSITUACAOAGEND WHEN '1' THEN 'Pendente'
                   WHEN '2' THEN 'Em andamento'
                   WHEN '3' THEN 'Cancelado'
                   WHEN '4' THEN 'Concluído'
                   WHEN '5' THEN 'Atrasado'
                   ELSE NULL END AS IDSITUACAOAGEND
                   FROM FCM_CHECKLISTAGEND";

        $std = $this->connection->prepare($sql);

        $std->execute();
        return $std->fetchAll();
    }

    public function taskScheduled ($parametro, $usersIds) {
        $sql = "SELECT CA.NRCHECKLISTAGEND, CA.NRLOCALCLIENTE, CA.NRCHECKLIST, CA.NRFUNCIONARIO, CA.IDSITUACAOAGEND,
        TO_CHAR(CA.DTHORAAGEND, 'DD/MM HH24:MI') DTHORAAGEND, CA.NMCHECKLISTAGEND, LC.NMLOCALCLIENTE, LC.NRLOCALCLIENTEPAI AS LOCALPAI,
        LCP.NMLOCALCLIENTE AS NMLOCALPAI, CHK.NMCHECKLIST, F.NMFUNCIONARIO,
                        CASE CA.IDSITUACAOAGEND WHEN '1' THEN 'Pendente'
                        WHEN '2' THEN 'Em andamento'
                        WHEN '3' THEN 'Cancelado'
                        WHEN '4' THEN 'Concluído'
                        WHEN '5' THEN 'Atrasado'
                        ELSE NULL END AS IDSITUACAOAGEND
                    FROM FCM_CHECKLISTAGEND CA
                    JOIN FCM_LOCALCLI LC
                    ON LC.NRLOCALCLIENTE = CA.NRLOCALCLIENTE
                    JOIN FCM_LOCALCLI LCP
                    ON LCP.NRLOCALCLIENTE = LC.NRLOCALCLIENTEPAI
                    JOIN FCM_CHECKLIST CHK
                    ON CA.NRCHECKLIST = CHK.NRCHECKLIST
                    JOIN FCM_FUNCIONARIO F
                    ON F.NRFUNCIONARIO = CA.NRFUNCIONARIO".$parametro."
                  AND CA.NRFUNCIONARIO IN ({$usersIds})
                  ORDER BY DTHORAAGEND";

        $std = $this->connection->prepare($sql);

        $std->execute();
        return $std->fetchAll();
    }

    //Funções da Tela Minhas Tarefas
    public function nextTaskCard ($usersIds) {
        $sql = "SELECT CA.NRCHECKLISTAGEND, CA.NRLOCALCLIENTE, CA.NRCHECKLIST, CA.NRFUNCIONARIO, CA.IDSITUACAOAGEND,
        TO_CHAR(CA.DTHORAAGEND, 'DD/MM HH24:MI') DTHORAAGEND, CA.NMCHECKLISTAGEND, LC.NMLOCALCLIENTE, LC.NRLOCALCLIENTEPAI AS LOCALPAI,
        LCP.NMLOCALCLIENTE AS NMLOCALPAI, CHK.NMCHECKLIST, F.NMFUNCIONARIO,
                  CASE CA.IDSITUACAOAGEND WHEN '1' THEN 'Pendente'
                  WHEN '2' THEN 'Em andamento'
                  WHEN '5' THEN 'Atrasado'
                  ELSE NULL END AS IDSITUACAOAGEND
              FROM FCM_CHECKLISTAGEND CA
              JOIN FCM_LOCALCLI LC
              ON LC.NRLOCALCLIENTE = CA.NRLOCALCLIENTE
              JOIN FCM_LOCALCLI LCP
              ON LCP.NRLOCALCLIENTE = LC.NRLOCALCLIENTEPAI
              JOIN FCM_CHECKLIST CHK
              ON CA.NRCHECKLIST = CHK.NRCHECKLIST
              JOIN FCM_FUNCIONARIO F
              ON F.NRFUNCIONARIO = CA.NRFUNCIONARIO
              WHERE CA.IDSITUACAOAGEND IN (1,2,5)
              AND F.NRFUNCIONARIO IN ({$usersIds})
              ORDER BY DTHORAAGEND";

        $std = $this->connection->prepare($sql);

        $std->execute();
        return $std->fetchAll();
    }

    // Update para alterar o status da tarefa
    // Quando iniciar a tarefa , passar o valor '2' / Quando finalizar, passar o valor '4'  / Quando reportar, passar o valor 3
    // DSJUSTCANCELAMENTO = Deve ser preenchido somente quando for reportar. Para as outras ações, deve ser passado "NULL"
    public function upStatusTask ($parametros) {

      $sql = "UPDATE FCM_CHECKLISTAGEND
                SET IDSITUACAOAGEND = :IDSITUACAOAGEND,
                DTULTATU = SYSDATE,
                DSJUSTCANCELAMENTO = :DSJUSTCANCELAMENTO
                WHERE NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

    // Update de finalização direta na tela de Minhas Tarefas
    public function upFinishTask($parametros) {

      $sql = "UPDATE FCM_TAREFAAGEND
                SET IDREALIZADO = 'S',
                DTULTATU = SYSDATE
              WHERE NRCHECKLISTAGEND = ".$parametros;

      $std = $this->connection->prepare($sql);
      $std->execute();
    }

    //Funções da Tela Detalhamento da Tarefa

    // Update de finalização do detalhamento
    // IDREALIZADO = Somente dos checks que foram marcados
    // (Nesse caso, deve ser fazer um ForEach pegando somente os que foram marcados e updatando 1 por 1 )
    public function upFinishDetailsTaks($parametros) {
      $sql = " UPDATE FCM_TAREFAAGEND
                SET IDREALIZADO = 'S',
                DTULTATU = SYSDATE,
                DSOBSTAREFAAGEND = :DSOBSTAREFAAGEND
              WHERE NRTAREFAAGEND = :NRTAREFAAGEND
              AND NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

      $std = $this->connection->prepare($sql);
      $std->execute($parametros);
    }

    // Funções da Tela de Detalhamento

    //Função que retorna as informações no card superior com o detalhamento da tarefa
    public function itensDetailsTask($parametros) {
      $sql = "SELECT TA.NRTAREFAAGEND, TA.NRCHECKLISTAGEND, TA.NRFUNCIONARIO, TO_CHAR(TA.DTHORATAREFAAGEND, 'DD/MM HH24:MI') DTHORATAREFAAGEND,
              TA.NRTAREFACHK, TA.IDREALIZADO, TF.NMTAREFA
               FROM FCM_TAREFAAGEND TA
               JOIN FCM_CHECKLISTAGEND  CA
               ON TA.NRCHECKLISTAGEND = CA.NRCHECKLISTAGEND
               JOIN FCM_TAREFACHK T
               ON T.NRTAREFACHK = TA.NRTAREFACHK
               JOIN FCM_TAREFA TF
               ON T.NRTAREFA = TF.NRTAREFA
               WHERE CA.NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

      $std = $this->connection->prepare($sql);

      $std->execute($parametros);
      return $std->fetchAll();
    }

    public function cardDetailsTask($parametros) {

      $sql = "SELECT CA.NRCHECKLISTAGEND, CA.NRLOCALCLIENTE, CA.NRCHECKLIST, CA.NRFUNCIONARIO, CA.IDSITUACAOAGEND,
        TO_CHAR(CA.DTHORAAGEND, 'DD/MM HH24:MI') DTHORAAGEND, CA.NMCHECKLISTAGEND, LC.NMLOCALCLIENTE, LC.NRLOCALCLIENTEPAI AS LOCALPAI,
        LCP.NMLOCALCLIENTE AS NMLOCALPAI, CHK.NMCHECKLIST, F.NMFUNCIONARIO,
                  CASE CA.IDSITUACAOAGEND WHEN '1' THEN 'Pendente'
                  WHEN '2' THEN 'Em andamento'
                  WHEN '5' THEN 'Atrasado'
                  ELSE NULL END AS IDSITUACAOAGEND
              FROM FCM_CHECKLISTAGEND CA
              JOIN FCM_LOCALCLI LC
              ON LC.NRLOCALCLIENTE = CA.NRLOCALCLIENTE
              JOIN FCM_LOCALCLI LCP
              ON LCP.NRLOCALCLIENTE = LC.NRLOCALCLIENTEPAI
              JOIN FCM_CHECKLIST CHK
              ON CA.NRCHECKLIST = CHK.NRCHECKLIST
              JOIN FCM_FUNCIONARIO F
              ON F.NRFUNCIONARIO = CA.NRFUNCIONARIO
              WHERE CA.NRCHECKLISTAGEND = :NRCHECKLISTAGEND";

      $std = $this->connection->prepare($sql);

      $std->execute($parametros);
      return $std->fetchAll();
    }

    public function statusCheck($param) {

      $sql = "SELECT COUNT(IDSITUACAOAGEND)
               FROM FCM_CHECKLISTAGEND
               WHERE IDSITUACAOAGEND = '2'
               AND NRFUNCIONARIO = :NRFUNCIONARIO";

      $std = $this->connection->prepare($sql);

      $std->execute($param);
      return $std->fetchAll();
    }

}
?>